@@ -41,7 +41,9 @@ UNIT_KILOMETERS = units.km
 UNIT_LUX = units.lx
 UNIT_METERS_PER_SECOND = units.m / units.sec
 UNIT_MILLIBARS = units.mbar
+UNIT_MILLIMETERS = units.mm
 UNIT_MILLIMETERS_PER_MINUTE = units.mm / units.min
+UNIT_MILLIMETERS_PER_HOUR = units.mm / units.hr
 UNIT_MINUTES = units.min
 UNIT_PERCENT = units.percent
 UNIT_SECONDS = units.sec
