@@ -2,7 +2,7 @@
 from __future__ import annotations
 
 from datetime import datetime, timezone
-from typing import Any
+from typing import Any, TypeVar
 
 from pint import Quantity
 
@@ -24,6 +24,7 @@ DIRECTIONS = [
     "NW",
     "NNW",
 ]
+T = TypeVar("T")  # pylint: disable=invalid-name
 UTC = timezone.utc
 
 
@@ -38,6 +39,11 @@ def degrees_to_cardinal(degree: float | Quantity[float]) -> str:
     ]
 
 
+def nvl(value: T | None, default: T) -> T:
+    """Return default if value is None, else value."""
+    return default if value is None else value
+
+
 def truebool(val: Any | None) -> bool:
     """Return `True` if the value passed in matches a "True" value, otherwise `False`.
 
